import sys
from pathlib import Path

from metadocker.cmdline.commands.base import Argument, Command
from metadocker.db.db import settings
from metadocker.register import load_env


class ConfigCommand(Command):
    NAME = "config"
    HELP = "Configure l'application\nEx metadocker config -l # liste les config\n" \
           "metadocker config my.key # renvoie la valeur de my.key\n" \
           "metadocker config \"my.key=my value\" # affctre la valeur \"my value\" à my.key"

    ARGUMENTS = [
        Argument("--list", "-l", action="store_true", help="Liste les configurations"),
        Argument("--short", "-s", action="store_true", help="N'affiche pas les clés"),
        Argument("args",  nargs="*", help="Les ")
    ]

    def run(self):
        if self.list or not self.args:
            for k, v in settings.items():
                print(f"{k}={v}")
            exit(0)

        for arg in self.args:
            if "=" in arg:
                key, _, value = arg.partition("=")
                settings[key] = value
            else:
                if arg in settings:
                    if self.short:
                        print(settings[arg])
                    else:
                        print(f"{arg}={settings[arg]}")
                else:
                    print(f"Clé {arg} introuvable", file=sys.stderr)
