import json
import os
import pickle
from pathlib import Path

from metadocker.common.errors import SimpleError


class _Config:
    _engine = pickle
    _INSTANCE = None
    DEFAULT_DATA = {
        "app.docker.max_depth" : 3,
        "app.docker.cache" : [],
    }
    def __init__(self):
        if _Config._INSTANCE is not None:
            raise ValueError(f"Impossible de lancer pluseir base de données")

        self.filename = self._get_path() / f"metadocker.{self._engine.__name__}"
        self.data = dict(self.DEFAULT_DATA)
        try:
            self.data.update(self._engine.loads(self.filename.read_bytes()))
        except Exception as err:
            print(f"Impossible de trouver la configuration dans {self.filename}. Création")
            self.save()

    def _get_path(self):
        return Path(os.environ.get("METADOCKER_CONF_DIR",
                                   Path(os.environ["HOME"]) / ".config" / "metadocker" )).resolve()


    def save(self):
        self.filename.parent.mkdir(exist_ok=True, parents=True)
        self.filename.write_bytes(self._engine.dumps(self.data))

    def __getitem__(self, item):
        return self.data[item]
    def __setitem__(self, item, value):
        self.data[item] = value
        self.save()

    def items(self):
        return self.data.items()

    def __contains__(self, item):
        return item in self.data

    def values(self):
        return self.data.values()

    def get(self, k, *args):
        return self.data.get(k, *args)

    @property
    def app_dir(self):
        if "app.dir" not in self.data:
            raise SimpleError(f"Option base_dir non définie. Merci d'utilser\n"
                              f"metadocker config \#app.dirr=/dossier/de/donne\"")


settings = _Config()